/*
 * $Id: OMStringTest.java,v 1.7 2004/10/26 18:32:22 mriem Exp $
 *
 * Copyright (c) 2001-2004, RIACA, Technische Universiteit Eindhoven (TU/e).
 * All Rights Reserved.
 *
 * ---------------------------------------------------------------------------
 *
 *  The contents of this file are subject to the RIACA Public License
 *  Version 1.0 (the "License"). You may not use this file except in
 *  compliance with the License. A copy of the License is available at
 *  http://www.riaca.win.tue.nl/
 *
 *  Alternatively, the contents of this file may be used under the terms
 *  of the GNU Lesser General Public license (the "LGPL license"), in which 
 *  case the provisions of the LGPL license are applicable instead of those 
 *  above. A copy of the LGPL license is available at http://www.gnu.org/
 *
 *  The Original Code is ROML -- the RIACA OpenMath Library. The Initial
 *  Developer of the Original Code is Manfred N. Riem.  Portions created
 *  by Manfred N. Riem are Copyright (c) 2001. All Rights Reserved.
 *
 *  Contributor(s):
 *
 *      Ernesto Reinaldo Barreiro, Arjeh M. Cohen, Hans Cuypers, Hans Sterk,
 *      Olga Caprotti
 *
 * ---------------------------------------------------------------------------
 */
package nl.tue.win.riaca.openmath.lang;

import junit.framework.*;

/**
 * A JUnit test for an OpenMath string. <p>
 *
 * @author Manfred N. Riem (mriem@manorrock.org)
 * @version $Revision: 1.7 $
 */
public class OMStringTest extends TestCase {
    /**
     * Constructor. <p>
     *
     * @param testName the name of the test.
     */
    public OMStringTest(java.lang.String testName) {
        super(testName);
    }
    
    /**
     * Static suite method. <p>
     *
     * @return the test suite.
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(OMStringTest.class);
        return suite;
    }
    
    /** 
     * Test of getType method, of class nl.tue.win.riaca.openmath.lang.OMString. 
     */
    public void testGetType() {
        OMString string = new OMString( "Hello there!" );
        assertTrue( string.getType().equals( "OMSTR" ) );
    }
    
    /** 
     * Test of setString method, of class nl.tue.win.riaca.openmath.lang.OMString. 
     */
    public void testSetString() {
        OMString string = new OMString( "hello there!" );
        string.setString( "Ooops" );
        assertTrue( string.getString().equals( "Ooops" ) );
    }
    
    /** 
     * Test of getString method, of class nl.tue.win.riaca.openmath.lang.OMString. 
     */
    public void testGetString() {
        OMString string = new OMString( "hello there!" );
        assertTrue( string.getString().equals( "hello there!" ) );
    }
    
    /** 
     * Test of isAtom method, of class nl.tue.win.riaca.openmath.lang.OMString. 
     */
    public void testIsAtom() {
        OMString string = new OMString( "hello" );
        assertTrue( string.isAtom() );
    }
    
    /** 
     * Test of isComposite method, of class nl.tue.win.riaca.openmath.lang.OMString. 
     */
    public void testIsComposite() {
        OMString string = new OMString( "hello" );
        assertTrue( !string.isComposite() );
    }
    
    /** 
     * Test of toString method, of class nl.tue.win.riaca.openmath.lang.OMString. 
     */
    public void testToString() {
        OMString string = new OMString( "hello" );
        assertTrue( string.toString().equals( "<OMSTR>hello</OMSTR>" ) );
    }
    
    /** 
     * Test of clone method, of class nl.tue.win.riaca.openmath.lang.OMString. 
     */
    public void testClone() {
        OMString string = new OMString( "hello" );
        OMString clone  = (OMString) string.clone();
        assertTrue( string.getString().equals( clone.getString() ) );
    }
    
    /** 
     * Test of copy method, of class nl.tue.win.riaca.openmath.lang.OMString. 
     */
    public void testCopy() {
        OMString string = new OMString( "hello" );
        OMString clone  = (OMString) string.clone();
        assertTrue( string.getString().equals( clone.getString() ) );
    }
    
    /**
     * Test of isSame method, of class nl.tue.win.riaca.openmath.lang.OMString. 
     */
    public void testIsSame() {
        OMString string1 = new OMString("hello");
        OMString string2 = new OMString("hello");
        
        assertTrue(string1.isSame(string2));
    }
    
    /**
     * Test of isValid method, of class nl.tue.win.riaca.openmath.lang.OMString.
     */
    public void testIsValid() {
        OMString string = new OMString("hello");
        
        assertTrue(string.isValid());
    }    
}
